#!/bin/bash
#SBATCH -A bsc32
#
#
#SBATCH --cpus-per-task=1
#SBATCH -n 1
#SBATCH -t 0-01:00:00
#SBATCH -J monarch-DA-viirs
#SBATCH -e out-logs/format-viirs-monarch-DA-data-%j.err
#SBATCH -o out-logs/format-viirs-monarch-DA-data-%j.out



module purge
module use /gpfs/projects/bsc32/software/suselinux/11/modules/all
module unuse /apps/modules/modulefiles/applications /apps/modules/modulefiles/compilers /apps/modules/modulefiles/tools /apps/modules/modulefiles/libraries /apps/modules/modulefiles/environment

module load SciPy-bundle/2019.10-foss-2019b-Python-3.7.4
module load GLib/2.62.0-GCCcore-8.3.0
module load dask/2022.2.0-foss-2019b-Python-3.7.4
module load xarray/0.19.0-foss-2019b-Python-3.7.4
module load netcdf4-python/1.5.3-foss-2019b-Python-3.7.4
module load geopandas/0.8.1-foss-2019b-Python-3.7.4

set -vx

#Path to the obs
datadir='/esarchive/obs/nasa/viirs_snpp_aerdb_l2/original_files/VIIRS/'
#Where to save final processed obs
finalobs='/esarchive/scratch/cmeikle/Projects/data/VIIRS/obsfinal/global/3hourly/centered'
#Uncertainty constants
# Error : sqrt((unca*AOD + uncb)**2 + uncc**2)
unca=0.2
uncb=0.05
uncc=0.02
#Initial and final date of the obs we want to preproc.
#Format: YYYYmmddHHMM
dateini='202006010000'
datefin='202006020000'
#Frequency interval we want to group our obs
#the frequency interval implies that the time slice YYYYmmddHH-1*lafreq_slice do not contains obs for YYYYmmddHH
#interval : [closed, open)
lafreqslice='H'
#center point longitudinal (E/W)
cenlon=0
#center point latitudinal (S/N)
cenlat=0
westbound=-180
southbound=-90
incrlat=0.1
incrlon=0.1
#Rotate coordinates (true/false)
rotate='false'

# Do we want to aggregate per model grid cell
avgdata='true'
# Min number of observations per grid cell >=
minobs=1

# Do we take the centre of the grid cell as the lat/lon
# If not then the avg lat/lon of the obs will be returned
# Only applies when avgdata='true'
cenlatlon='true'


#path to python script
pathtopy='/esarchive/scratch/cmeikle/git_projects/mapies/mapies/preproc'

cd ${pathtopy}
echo ${pathtopy}

#f2py3 -m elwriterdaf90 -c ../libs/elwriterdaf90.f90

echo "Running python script"
time python VIIRSAODFormatter.py -d ${datadir} -f ${finalobs} -a ${unca} -b ${uncb} -c ${uncc} -q ${dateini} -w ${datefin} -e ${lafreqslice} -m ${cenlon} -l ${cenlat} -bs ${southbound} -bw ${westbound} -rlat ${incrlat} -rlon ${incrlon} -r ${rotate} -avg ${avgdata} -min ${minobs} -cen ${cenlatlon}

exit
