#!/bin/bash
#SBATCH -A bsc32
#
#
#SBATCH --cpus-per-task=1
#16
#SBATCH -n 1
#SBATCH -t 0-01:00:00
#SBATCH -J monarch-DA-cams
#SBATCH -e /esarchive/scratch/cmeikle/git_projects/mapies/mapies/preproc/run/out-logs/format-cams-monarch-DA-data-%j.err
#SBATCH -o /esarchive/scratch/cmeikle/git_projects/mapies/mapies/preproc/run/out-logs/format-cams-monarch-DA-data-%j.out
#BSUB -x


module purge
module use /gpfs/projects/bsc32/software/suselinux/11/modules/all
module unuse /apps/modules/modulefiles/applications /apps/modules/modulefiles/compilers /apps/modules/modulefiles/tools /apps/modules/modulefiles/libraries /apps/modules/modulefiles/environment

module load SciPy-bundle/2019.10-foss-2019b-Python-3.7.4
module load GLib/2.62.0-GCCcore-8.3.0
module load netcdf4-python/1.5.3-foss-2019b-Python-3.7.4


#Path to the data

#dataDir='/esarchive/obs/meteofrance/eionet-cams2_40/original_files/' #Analysis data
dataDir='/esarchive/obs/ineris/eionet-cams2_40-vra/daily/' # VRA reanalysis data
#dataDir='/esarchive/obs/ineris/eionet-cams2_40-ira/daily/' #ira reanalysis data
#Path to the file containing conversion factors of the units
#unitChangeFile='/esarchive/obs/ecmwf/eea-cams50/original_files/unit_change'
unitChangeFile='/esarchive/scratch/cmeikle/git_projects/mapies/mapies/preproc/tools/unit_change'
#element(s) to process
element='O3 NO2 SO2 CO PM10 PM25'
#Path to the rotated observations without final processing 
#obsnorotatedsave='/esarchive/obs/ecmwf/eea-cams50/original_files/tmp/obsrotated/'
obsnorotatedsave='/esarchive/scratch/cmeikle/git_projects/mapies/mapies/outputs/obsrotated'
#Path to the final result (observations)
#obsfinalsave='/esarchive/obs/ecmwf/eea-cams50/original_files/tmp/obsfinal/separated_gases_particles/particles/'
obsfinalsave='/esarchive/scratch/cmeikle/git_projects/mapies/mapies/outputs/obsfinal'
#Path to fortran executable (rotated.exe)
#fortranexec='/esarchive/scratch/cmeikle/Projects/monarch-DA/rotated.exe'
fortranexec='/esarchive/scratch/cmeikle/Projects/monarch-DA/obs_preproc/libs/rotated.exe'
#Option to save all observations in the same file: t(True) f(False)
save_all_obs_in_one='f'
cenlon='10.0'
cenlat='51.0'
westbound='-35.0'
southbound='-27.0'
#Uncertainty constants
# Error : obs_value*uncb + uncc)
# Uncertainties linked to species, make sure that ' and " are kept the same or python will through an argparse error
# Also make sure that there are no spaces or argparse will treet it as a separate variable all together
uncb='{"O3":0.01,"CO":0.01,"NO2":0.005,"SO2":0.005,"PM10":0.0001,"PM25":0.0005}'
uncc='{"O3":0.001,"CO":0.001,"NO2":0.005,"SO2":0.0005,"PM10":0.00001,"PM25":0.00005}'

#start date

iDate='202003020000'
#final date
fDate='202003030000'
#ANALYSIS(an) OR REANALYSIS(re)
anre='re'

unitChangeFile_anre=${unitChangeFile}'_'${anre}

#Path to python script directory
pathtopy='/esarchive/scratch/cmeikle/git_projects/mapies/mapies/preproc/'
cd ${pathtopy}
echo ${pathtopy}

#run if fortran file not compiled

f2py3 -m elwriterdaf90 -c ./tools/elwriterdaf90.f90

time python camsFormatter.py -d ${dataDir} -u ${unitChangeFile_anre} -e ${element} -x ${fortranexec} -o ${obsnorotatedsave} -f ${obsfinalsave} -a ${save_all_obs_in_one} -m ${cenlon} -l ${cenlat} -w ${westbound} -q ${southbound} -b ${uncb} -c ${uncc} -i ${iDate} -t ${fDate} -r ${anre}

chmod -R 775 ${obsfinalsave}
exit
